Crate kcr_app_kiegroup_org

Crate kcr_app_kiegroup_org 

This crate contains kube-rs compatible bindings for Kubernetes custom resources for the app.kiegroup.org group. Each binding is generated with kopium, updated and released weekly.

Available Custom Resources

app.kiegroup.org/v1beta1

  • KogitoBuild
  • KogitoInfra
  • KogitoRuntime
  • KogitoSupportingService

Modules

v1beta1